@@ -16,50 +16,30 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#include <unistd.h>
 #include <errno.h>
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
 
 #include <atalk/adouble.h>
-#include <atalk/util.h>
-#include <atalk/vfs.h>
 #include <atalk/afp.h>
-#include <atalk/logger.h>
 #include <atalk/ea.h>
 #include <atalk/globals.h>
+#include <atalk/logger.h>
 #include <atalk/netatalk_conf.h>
+#include <atalk/util.h>
+#include <atalk/vfs.h>
 
-#include "volume.h"
 #include "desktop.h"
 #include "directory.h"
-#include "fork.h"
 #include "extattrs.h"
+#include "fork.h"
+#include "volume.h"
 
 static const char *ea_finderinfo = "com.apple.FinderInfo";
 static const char *ea_resourcefork = "com.apple.ResourceFork";
 
 
-#ifdef DEBUG
-static void hexdump(void *m, size_t l) {
-    char *p = m;
-    int count = 0, len;
-    char buf[100];
-    char *bufp = buf;
-
-    while (l--) {
-        len = sprintf(bufp, "%02x ", *p++);
-        bufp += len;
-        count++;
-
-        if ((count % 16) == 0) {
-            LOG(log_debug9, logtype_afpd, "%s", buf);
-            bufp = buf;
-        }
-    }
-}
-#endif
-
 /***************************************
  * AFP funcs
  ****************************************/
@@ -72,7 +52,8 @@ static void hexdump(void *m, size_t l) {
 int afp_listextattr(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_, char *rbuf, size_t *rbuflen)
 {
     int                 ret, oflag = 0, adflags = 0, fd = -1;
-    uint16_t            vid, bitmap, uint16;
+    uint16_t            vid;
+    uint16_t            bitmap;
     uint32_t            did, maxreply, tmpattr;
     struct vol          *vol;
     struct dir          *dir;
@@ -507,4 +488,3 @@ int afp_remextattr(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_, char *rbuf _
 
     return ret;
 }
-
